import os
import json

print("[nuclyr|config] ~/.nuclyr loaded...")

config = {
    "webdriver" :   "Edge",
    "driver_loc":   "",
    "output"    : False,
    "outputDir" : "./output",
    "installDir":   os.path.dirname(__file__)     
}

if not os.path.exists(os.path.join(os.path.expanduser('~'),".nuclyr")):
    json.dump(config, open(os.path.join(os.path.expanduser('~'),".nuclyr"),"w"))

def Get(option):    
    jsonData = json.load(open(os.path.join(os.path.expanduser('~'),".nuclyr"),"r"))
    return jsonData[option]

def Set(option, string):
    jsonData = json.load(open(os.path.join(os.path.expanduser('~'),".nuclyr"),"r"))
    jsonData[option] = string
    json.dump(jsonData, open(os.path.join(os.path.expanduser('~'),".nuclyr"),"w"))
    Show()

def Show():
    print("[nuclyr|config] New content of ~/.nuclyr ...")
    print(json.load(open(os.path.join(os.path.expanduser('~'),".nuclyr"),"r")))
    



import pandas as pd
import requests
import io
import os

def massExcess(Z,A, model="RIPL"):
    this_dir, this_filename = os.path.split(__file__)

    df=pd.read_csv(os.path.join(this_dir,"data","ripl","mass-frdm95.dat"), skiprows=(0,1,2,3), sep=",", names=["Z","A","Element","Flag","Mexp","MErr","Mth","Emic","beta2","beta3","beta4","beta6"], header=0)

    if model == "RIPL":
        df=pd.read_csv(os.path.join(this_dir,"data","ripl","mass-frdm95.dat"), skiprows=(0,1,2,3), sep=",", names=["Z","A","Element","Flag","Mexp","MErr","Mth","Emic","beta2","beta3","beta4","beta6"], header=0)
        return df["Mexp"].loc[(df["Z"] == Z) & (df["A"]==A)].values[0], df["MErr"].loc[(df["Z"] == Z) & (df["A"]==A)].values[0]

    if model == "AMDC":
        df=pd.read_csv(os.path.join(this_dir,"data","amdc","mass16.dat"),sep=",", skiprows=0, names=["1N-Z","N","Z","A","EL","O","Mexp","MErr","BE","BEErr","DECAY"], header=0)
        return df["Mexp"].loc[(df["Z"] == Z) & (df["A"]==A)].values[0]/1e3, df["MErr"].loc[(df["Z"] == Z) & (df["A"]==A)].values[0]/1e3
    

def abundance(Z,A):
    this_dir, this_filename = os.path.split(__file__)
    df=pd.read_csv(os.path.join(this_dir,"data","ripl","abundance.dat"))
    return df["abundance"].loc[(df["Z"] == Z) & (df["A"]==A)].values[0], df["uncert."].loc[(df["Z"] == Z) & (df["A"]==A)].values[0]


from setuptools import setup, find_packages
import os
import ast
from pip import __file__ as pip_loc

def extract_values(source_file, desired_vars):
    with open(source_file) as f:
        for line in f:
            if any(line.startswith(var) for var in desired_vars):
                parsed = ast.parse(line).body[0]
                yield parsed.targets[0].id, parsed.value.s

with open("README.md", "r") as fh:
    long_description = fh.read()
  
package_name="nuclyr"

data_file_source = os.path.join(os.path.dirname(__file__), package_name)
data_install_folder = os.path.join(os.path.dirname(os.path.dirname(pip_loc)), package_name)

for filename in os.listdir(data_file_source):
  all_data_files = os.path.join(data_file_source, filename)

data_files = [(data_install_folder, all_data_files)]

setup(name='nuclyr',
      version='0.16',
      author='Philipp Scholz',
      author_email='pscholz@outlook.com',
      license='MIT',
      packages=["nuclyr"],
      package_dir={package_name: package_name},
      #data_files=[("","ripl/abundance.dat"), ("","ripl/mass-frdm95.dat"),("","./admc/mass16.dat")],
      include_package_data = True,
      url="https://github.com/phScholz/nuclyr",
      description="An utility package for nuclear data.",
      long_description=long_description,
      long_description_content_type='text/markdown',
      zip_safe=False,
      install_requires=['selenium','pandas'])